| leg_comp | R Documentation |
Compose a map legend with several elements. The "type" argument defines the legend type. Please note that some arguments are available for all types of legend and some others are only relevant for specific legend types.
leg_comp(
leg,
type,
val,
pal = "Inferno",
alpha = NULL,
col = "tomato4",
inches = 0.3,
val_max = NULL,
symbol = "circle",
self_adjust = FALSE,
lwd = 0.7,
border = "#333333",
pch = 1:seq_along(val),
cex = rep(1, length(val)),
title = "Legend Title",
val_rnd = 0,
val_dec = ".",
val_big = "",
col_na = "white",
cex_na = 1,
pch_na = 4,
no_data = FALSE,
no_data_txt = "No Data",
box_border = "333333",
box_cex = c(1, 1),
horiz = FALSE
)
leg |
legend object |
type |
type of legend:
|
val |
vector of value(s) (for "prop" and "prop_line", at least c(min, max) for "cont"), vector of categories (for "symb", "typo", "typo_line"), break labels (for "choro", "choro_point", "choro_line", "choro_symb", and "grad_line"), histogram parameters (for "histo"). |
pal |
a color palette name or a vector of colors |
alpha |
opacity, in the range [0,1] |
col |
color of the symbols (for "prop") or color of the lines (for "prop_line" and "grad_line") |
inches |
size of the largest symbol (radius for circles, half width for squares) in inches |
val_max |
maximum value corresponding to the largest symbol or line |
symbol |
type of symbols, 'circle' or 'square' |
self_adjust |
if TRUE values are self-adjusted to keep min, max and intermediate rounded values |
lwd |
width(s) of the symbols borders (for "prop", "symb", "choro_point", "choro_symb"), width of the largest line (for "prop_line"), line width (for "choro_line" and "typo_line"), vector of line widths (for "grad_line") |
border |
symbol border color(s) |
pch |
type(s) of the symbols (0:25) |
cex |
size(s) of the symbols |
title |
title of the legend |
val_rnd |
number of decimal places of the values in the legend |
val_dec |
decimal separator |
val_big |
thousands separator |
col_na |
color for missing values |
cex_na |
size of the symbols for missing values |
pch_na |
type of the symbols for missing values |
no_data |
if TRUE a "missing value" box is plotted |
no_data_txt |
label for missing values |
box_border |
border color of legend boxes |
box_cex |
width and height size expansion for boxes, histogram or lines |
horiz |
if TRUE plot an horizontal legend |
A list of legends parameters is returned.
# minimal example
plot.new()
plot.window(xlim = c(0, 1), ylim = c(0, 1), asp = 1)
box()
leg_comp(type = "prop", val = c(10, 50, 100)) |>
leg_comp(type = "typo", val = c("A", "B", "C")) |>
leg_draw()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.